==> wetkit-7.x-1.0-rc24-no-core.tar.gz: wetkit/README.md <==
<img alt="Banner" src="http://dl.dropbox.com/u/38413195/banner.jpeg" title="By Y Anderson (Own work) [CC-BY-SA-3.0 (http://creativecommons.org/licenses/by-sa/3.0" class="img-responsive">

# Web Experience Toolkit: Drupal WxT

[![Build Status][travisci-badge]][travisci]
[![Selenium Test Status][selenium-badge]][selenium]

## Important Links

- Documentation Website: [wiki.drupalwxt.org][docsite]
- Screencasts: [youtube][youtube]
- Drupal Repository: [drupal.org/project/wetkit][drupal]
- GitHub Repository: [wet-boew/wet-boew-drupal][github]
- Live Demo: [responsinator][responsinator]
- Run it Now: [simplytest.me][simplytest]
- Issue Queue: [Drupal][issue-drupal] (Primary)
- Issue Queue: [GitHub][issue-github]

## Overview

The Drupal WxT distribution is a web content management system which assists in building and maintaining innovative Web sites that are accessible, usable, and interoperable. This distribution is open source software and free for use by departments and external Web communities. This distribution relies and integrates extensively on the [WET-BOEW jQuery Framework][wet-boew] to leverage much of the rendering and overall markup.

Development has been tailored for organizations that need to comply with standards for accessibility and bilingualism or that simply need a distribution that allows them to get up and running quickly using a carefully curated selection of modules that can support common enterprise business requirements.

## Installation Methods

- Pre-Built Distribution: [drupal.org/project/wetkit][drupal] (Novice Users)
- Drush Make: [Documentation Page][docsite-drush-make] (Intermediate Users)
- Vagrant Virtual Machine: [sylus/vagrant-normandy][vagrant-normandy] (Advanced Users)

## Version History

### Changelog

- [CHANGELOG.md][changelog]

### Releases

- [Drupal.org][release-drupal]
- [GitHub][release-github]

## License and Developer(s)

Developer:: [William Hearn][sylus] (<william.hearn@statcan.gc.ca>) // [![endorse][coderwall-badge]][coderwall]

Contributor(s): https://github.com/wet-boew/wet-boew-drupal/graphs/contributors

Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at:

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.

<!-- Links Referenced -->

[sylus]:                http://coderwall.com/sylus

[changelog]:            https://github.com/wet-boew/wet-boew-drupal/blob/7.x-1.x/CHANGELOG.md
[coderwall]:            http://coderwall.com/sylus
[coderwall-badge]:      http://api.coderwall.com/sylus/endorsecount.png
[docsite]:              http://wiki.drupalwxt.org
[docsite-drush-make]:   http://wiki.drupalwxt.org/concepts/drush-make
[drupal]:               http://drupal.org/project/wetkit
[github]:               https://github.com/wet-boew/wet-boew-drupal
[issue-drupal]:         https://drupal.org/project/issues/wetkit
[issue-github]:         https://github.com/wet-boew/wet-boew-drupal/issues
[release-drupal]:       https://drupal.org/node/1972380/release
[release-github]:       https://github.com/wet-boew/wet-boew-drupal/releases
[responsinator]:        http://responsinator.com/?url=drupalwxt.org
[selenium]:             https://saucelabs.com/u/sylus
[selenium-badge]:       https://saucelabs.com/buildstatus/sylus
[simplytest]:           http://simplytest.me/project/wetkit/7.x-1.x
[travisci]:             https://travis-ci.org/wet-boew/wet-boew-drupal
[travisci-badge]:       https://secure.travis-ci.org/wet-boew/wet-boew-drupal.png?branch=7.x-1.x
[vagrant-normandy]:     https://github.com/sylus/vagrant-normandy
[wet-boew]:             https://github.com/wet-boew/wet-boew
[youtube]:              http://www.youtube.com/playlist?list=PLjIClrDa-_ZFwO-0sT_y6PGljSdbYztwi

==> wetkit-7.x-1.5-no-core.tar.gz: wetkit/README.md <==
<img alt="Banner" src="http://dl.dropbox.com/u/38413195/banner.jpeg" title="By Y Anderson (Own work) [CC-BY-SA-3.0 (http://creativecommons.org/licenses/by-sa/3.0" class="img-responsive">

# Web Experience Toolkit: Drupal WxT

[![Build Status][travisci-badge]][travisci]
[![Selenium Test Status][selenium-badge]][selenium]

## Important Links

- Documentation Website: [wiki.drupalwxt.org][docsite]
- Screencasts: [youtube][youtube]
- Drupal Repository: [drupal.org/project/wetkit][drupal]
- GitHub Repository: [wet-boew/wet-boew-drupal][github]
- Live Demo: [responsinator][responsinator]
- Run it Now: [simplytest.me][simplytest]
- Issue Queue: [Drupal][issue-drupal] (Primary)
- Issue Queue: [GitHub][issue-github]

## Overview

The Drupal WxT distribution is a web content management system which assists in building and maintaining innovative Web sites that are accessible, usable, and interoperable. This distribution is open source software and free for use by departments and external Web communities. This distribution relies and integrates extensively on the [WET-BOEW jQuery Framework][wet-boew] to leverage much of the rendering and overall markup.

Development has been tailored for organizations that need to comply with standards for accessibility and bilingualism or that simply need a distribution that allows them to get up and running quickly using a carefully curated selection of modules that can support common enterprise business requirements.

## Installation Methods

- Pre-Built Distribution: [drupal.org/project/wetkit][drupal] (Novice Users)
- Drush Make: [Documentation Page][docsite-drush-make] (Intermediate Users)
- Vagrant Virtual Machine: [sylus/vagrant-normandy][vagrant-normandy] (Advanced Users)

## Version History

### Changelog

- [CHANGELOG.md][changelog]

### Releases

- [Drupal.org][release-drupal]
- [GitHub][release-github]

## License and Developer(s)

Developer:: [William Hearn][sylus] (<william.hearn@statcan.gc.ca>) // [![endorse][coderwall-badge]][coderwall]

Contributor(s): https://github.com/wet-boew/wet-boew-drupal/graphs/contributors

Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at:

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.

<!-- Links Referenced -->

[sylus]:                http://coderwall.com/sylus

[changelog]:            https://github.com/wet-boew/wet-boew-drupal/blob/7.x-1.x/CHANGELOG.md
[coderwall]:            http://coderwall.com/sylus
[coderwall-badge]:      http://api.coderwall.com/sylus/endorsecount.png
[docsite]:              http://wiki.drupalwxt.org
[docsite-drush-make]:   http://wiki.drupalwxt.org/architecture/drush-make
[drupal]:               http://drupal.org/project/wetkit
[github]:               https://github.com/wet-boew/wet-boew-drupal
[issue-drupal]:         https://drupal.org/project/issues/wetkit
[issue-github]:         https://github.com/wet-boew/wet-boew-drupal/issues
[release-drupal]:       https://drupal.org/node/1972380/release
[release-github]:       https://github.com/wet-boew/wet-boew-drupal/releases
[responsinator]:        http://responsinator.com/?url=drupalwxt.org
[selenium]:             https://saucelabs.com/u/sylus
[selenium-badge]:       https://saucelabs.com/buildstatus/sylus
[simplytest]:           http://simplytest.me/project/wetkit/7.x-1.x
[travisci]:             https://travis-ci.org/wet-boew/wet-boew-drupal
[travisci-badge]:       https://travis-ci.org/wet-boew/wet-boew-drupal.png?branch=7.x-1.x
[vagrant-normandy]:     https://github.com/sylus/vagrant-normandy
[wet-boew]:             https://github.com/wet-boew/wet-boew
[youtube]:              http://www.youtube.com/playlist?list=PLjIClrDa-_ZFwO-0sT_y6PGljSdbYztwi
